from string_date_controller import get_first_date_of_month, get_last_date_of_month

def format_regex_for_snapshot(menu_code, fund_code, date_ref=None):
    if date_ref:
        date_ref = date_ref.replace('-', '')
        regex = f'menu{menu_code}-code{fund_code}-at{date_ref}'
    else:
        regex = f'menu{menu_code}-code{fund_code}'
    return regex

def format_regex_for_timeseries(menu_code, fund_code):
    regex = f'menu{menu_code}-code{fund_code}'
    return regex

def format_regex_for_period(menu_code, fund_code, start_date=None, end_date=None, date_ref=None):
    if date_ref and start_date==None and end_date==None:
        start_date = get_first_date_of_month(date_ref)
        end_date = get_last_date_of_month(date_ref)
    regex = f'menu{menu_code}-code{fund_code}-between{start_date.replace("-", "")}-and{end_date.replace("-", "")}'
    return regex

def format_regex_for_bbg_price(ticker_bbg):
    regex = f'dataset-timeseries-bbg-{ticker_bbg}-PX_LAST'
    return regex

def format_regex_for_market(market_name, date_ref=None):
    if date_ref:
        date_ref = date_ref.replace('-', '')
        regex = f'dataset-bbg-{market_name}_market-at{date_ref}'
    else:
        regex = f'dataset-bbg-{market_name}_market-'
    return regex

def format_regex_for_index_market(ticker_bbg_index, date_ref=None):
    if date_ref:
        date_ref = date_ref.replace('-', '')
        regex = f'dataset-bbg-{ticker_bbg_index}-market-at{date_ref}'
    else:
        regex = f'dataset-bbg-{ticker_bbg_index}-market-'
    return regex



from setuptools import setup, find_packages

setup(
    name='financial_dataset_loader',
    version='0.2.4',
    packages=find_packages(),
    install_requires=[
        'aws-s3-controller',
        'string-date-controller',
        'shining_pebbles',
    ],
    author='June Young Park',
    author_email='juneyoungpaak@gmail.com',
    description='A Python module for loading financial datasets from various sources',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/nailen1/financial_dataset_loader.git',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: Financial and Insurance Industry',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Office/Business :: Financial',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.11',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.11',
    keywords='financial data loader dataset aws s3',
)



import os

BASE_DIR = 'data'

FILE_FOLDER = {
    '2160': os.path.join(BASE_DIR, 'dataset-menu2160'),
    '2160-snapshot': os.path.join(BASE_DIR, 'dataset-menu2160-snapshot'),
    '2205': os.path.join(BASE_DIR, 'dataset-menu2205'),
    '2205-snapshot': os.path.join(BASE_DIR, 'dataset-menu2205-snapshot'),
    '4165': os.path.join(BASE_DIR, 'dataset-menu4165'),
    '8186-snapshot': os.path.join(BASE_DIR, 'dataset-menu8186-snapshot'),
    '2110': os.path.join(BASE_DIR, 'dataset-menu2110'),
    '3412': os.path.join(BASE_DIR, 'dataset-menu3412'),
    '3421': os.path.join(BASE_DIR, 'dataset-menu3421'),
    '3233': os.path.join(BASE_DIR, 'dataset-menu3233'),
    'fund': os.path.join(BASE_DIR, 'dataset-fund'),
    'market': os.path.join(BASE_DIR, 'dataset-market'),
    'index': os.path.join(BASE_DIR, 'dataset-index'),
    'currency': os.path.join(BASE_DIR, 'dataset-currency'),
    'equity': os.path.join(BASE_DIR, 'dataset-equity'),
}

BUCKET_SYSTEM = 'dataset-system'
BUCKET_BBG = 'dataset-bbg'

BUCKET_PREFIX = {
    '2160': 'dataset-menu2160',
    '2160-snapshot': 'dataset-menu2160-snapshot',
    '2205': 'dataset-menu2205',
    '2205-snapshot': 'dataset-menu2205-snapshot',
    '4165': 'dataset-menu4165',
    '8186-snapshot': 'dataset-menu8186-snapshot',
    '2110': 'dataset-menu2110',
    '3412': 'dataset-menu3412',
    '3421': 'dataset-menu3421',
    '3233': 'dataset-menu3233',
    'market': 'dataset-market',
    'index': 'dataset-index',
    'currency': 'dataset-currency',
    'equity': 'dataset-equity',
}